package com.dhcc.finance.main.service;

import java.util.List;

import com.dhcc.common.model.CurrencyMeta;
import com.dhcc.common.model.response.RestfulResponse;
import com.dhcc.finance.main.domain.CwGlTransferdetail;
import com.dhcc.finance.main.model.CwGlTransferdetailAndSubName;
import com.github.pagehelper.PageInfo;

public interface CwGlTransferdetailService {

	RestfulResponse<PageInfo<CwGlTransferdetailAndSubName>, CurrencyMeta> searchCwGlTransferByNameLike(String pkTransfer,
			int pageNum, int pageSize, int navigatePages);

	RestfulResponse<Object, CurrencyMeta> deleteCwGlTransferdetail(String pkTransferdetail);

	RestfulResponse<Object, CurrencyMeta> addCwGlTransfer(CwGlTransferdetail cwGlTransferdetail, String pkTransfer);

	RestfulResponse<Object, CurrencyMeta> updateCwGlTransfer(CwGlTransferdetail cwGlTransferdetail);

	RestfulResponse<List<CwGlTransferdetail>, CurrencyMeta> searchCwGlTransferdetail(String pkTransfer);

	RestfulResponse<Object, CurrencyMeta> updateCwGlTransferByPkForBatch(List<String> pkDetailList);

}
